zeitsprung |version|
====================

This package provides a scraper for www.zeitsprung.fm, a great history podcast.
To get the metadata and audio files of all episodes from the website, simply import and run the scraper.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   modules
   contributing
   authors
   history
